remove_suffix_tag

Function remove_suffix_tag 

fn remove_suffix_tag(name: &str) -> Option<&str>
If the variable name has a country tag at the end, return it with that tag removed. Otherwise return None.